import math

time: float = 0.0

# Initial assignments
P = math.inf
Q = float("-inf")
R = math.nan
y0 = []
variable_names = []


def model(time: float, variables: tuple[float, ...]) -> tuple[float, ...]:
    return


def derived(time: float, variables: tuple[float, ...]) -> dict[str, float]:
    return {}
