import math

time: float = 0.0
C: float = 1.00000000000000
S0_stoich: float = 0.0
S1_stoich: float = 0.0
S2_stoich: float = 0.0
S3_stoich: float = 0.0
S4_stoich: float = 0.0
S5_stoich: float = 0.0
S6_stoich: float = 0.0
S7_stoich: float = 0.0
S8_stoich: float = 0.0
S9_stoich: float = 0.0
S10_stoich: float = 0.0
S11_stoich: float = 0.0
S12_stoich: float = 0.0
S13_stoich: float = 0.0
S14_stoich: float = 0.0
S15_stoich: float = 0.0
S16_stoich: float = 0.0
S17_stoich: float = 0.0
S18_stoich: float = 0.0
S19_stoich: float = 0.0
S20_stoich: float = 0.0
S21_stoich: float = 0.0
S22_stoich: float = 0.0
S23_stoich: float = 0.0
S24_stoich: float = 0.0
S25_stoich: float = 0.0
S26_stoich: float = 0.0
S27_stoich: float = 0.0
S28_stoich: float = 0.0
S29_stoich: float = 0.0
S30_stoich: float = 0.0
S31_stoich: float = 0.0
S32_stoich: float = 0.0
S33_stoich: float = 0.0
S34_stoich: float = 0.0
S35_stoich: float = 0.0
S36_stoich: float = 0.0
S37_stoich: float = 0.0
S38_stoich: float = 0.0
S39_stoich: float = 0.0
S40_stoich: float = 0.0
S41_stoich: float = 0.0
S42_stoich: float = 0.0
S43_stoich: float = 0.0
S44_stoich: float = 0.0
S45_stoich: float = 0.0
S46_stoich: float = 0.0
S47_stoich: float = 0.0
S48_stoich: float = 0.0
S49_stoich: float = 0.0
S50_stoich: float = 0.0
S51_stoich: float = 0.0
S0: float = 0.0
S1: float = 0.0
S2: float = 0.0
S3: float = 0.0
S4: float = 0.0
S5: float = 0.0
S6: float = 0.0
S7: float = 0.0
S8: float = 0.0
S9: float = 0.0
S10: float = 0.0
S11: float = 0.0
S12: float = 0.0
S13: float = 0.0
S14: float = 0.0
S15: float = 0.0
S16: float = 0.0
S17: float = 0.0
S18: float = 0.0
S19: float = 0.0
S20: float = 0.0
S21: float = 0.0
S22: float = 0.0
S23: float = 0.0
S24: float = 0.0
S25: float = 0.0
S26: float = 0.0
S27: float = 0.0
S28: float = 0.0
S29: float = 0.0
S30: float = 0.0
S31: float = 0.0
S32: float = 0.0
S33: float = 0.0
S34: float = 0.0
S35: float = 0.0
S36: float = 0.0
S37: float = 0.0
S38: float = 0.0
S39: float = 0.0
S40: float = 0.0
S41: float = 0.0
S42: float = 0.0
S43: float = 0.0
S44: float = 0.0
S45: float = 0.0
S46: float = 0.0
S47: float = 0.0
S48: float = 0.0
S49: float = 0.0
S50: float = 0.0
S51: float = 0.0

# Initial assignments
dS0_stoich = math.e
dS1_stoich = math.exp(math.e)
dS2_stoich = 1
dS3_stoich = 1
dS4_stoich = math.pi
dS5_stoich = 1.04719755119660
dS6_stoich = (1 / 2) * math.pi
dS7_stoich = -0.523598775598299
dS8_stoich = 1.22777238637419
dS9_stoich = -1.43067687253053
dS10_stoich = 1
dS11_stoich = 4
dS12_stoich = -4
dS13_stoich = -0.947721602131112
dS14_stoich = 0.975897449330606
dS15_stoich = 1
dS16_stoich = math.e
dS17_stoich = 2.15976625378492
dS18_stoich = -5
dS19_stoich = 9
dS20_stoich = -1.60943791243410
dS21_stoich = 0
dS22_stoich = -1.6094379124341 / math.log(10)
dS23_stoich = 0
dS24_stoich = 1
dS25_stoich = 4
dS26_stoich = 5.56228172775440
dS27_stoich = 16
dS28_stoich = 9.61000000000000
dS29_stoich = 2
dS30_stoich = 2.72029410174709
dS31_stoich = 0.863209366648874
dS32_stoich = 0
dS33_stoich = 0.373876664830236
dS34_stoich = 0
dS35_stoich = 2.01433821447683
dS36_stoich = -math.tan(6)
dS37_stoich = 1.13949392732455
dS38_stoich = -1.02298638367130
dS39_stoich = 4.93315487558689
dS40_stoich = 0.304520293447143
dS41_stoich = 2.82831545788997
dS42_stoich = 1.12099946637054
dS43_stoich = 1.14109666064347
dS44_stoich = -1.47112767430373
dS45_stoich = math.asinh(99)
dS46_stoich = 0.802881971289134
dS47_stoich = -0.867300527694053
dS48_stoich = 1.51330668842682
dS49_stoich = 5.29834236561059
dS50_stoich = 1
dS51_stoich = 0
J0 = 1
J1 = 1
J2 = 1
J3 = 1
J4 = 1
J5 = 1
J6 = 1
J7 = 1
J8 = 1
J9 = 1
J10 = 1
J11 = 1
J12 = 1
J13 = 1
J14 = 1
J15 = 1
J16 = 1
J17 = 1
J18 = 1
J19 = 1
J20 = 1
J21 = 1
J22 = 1
J23 = 1
J24 = 1
J25 = 1
J26 = 1
J27 = 1
J28 = 1
J29 = 1
J30 = 1
J31 = 1
J32 = 1
J33 = 1
J34 = 1
J35 = 1
J36 = 1
J37 = 1
J38 = 1
J39 = 1
J40 = 1
J41 = 1
J42 = 1
J43 = 1
J44 = 1
J45 = 1
J46 = 1
J47 = 1
J48 = 1
J49 = 1
J50 = 1
J51 = 1
y0 = [
    S0,
    S0_stoich,
    S1,
    S10,
    S10_stoich,
    S11,
    S11_stoich,
    S12,
    S12_stoich,
    S13,
    S13_stoich,
    S14,
    S14_stoich,
    S15,
    S15_stoich,
    S16,
    S16_stoich,
    S17,
    S17_stoich,
    S18,
    S18_stoich,
    S19,
    S19_stoich,
    S1_stoich,
    S2,
    S20,
    S20_stoich,
    S21,
    S21_stoich,
    S22,
    S22_stoich,
    S23,
    S23_stoich,
    S24,
    S24_stoich,
    S25,
    S25_stoich,
    S26,
    S26_stoich,
    S27,
    S27_stoich,
    S28,
    S28_stoich,
    S29,
    S29_stoich,
    S2_stoich,
    S3,
    S30,
    S30_stoich,
    S31,
    S31_stoich,
    S32,
    S32_stoich,
    S33,
    S33_stoich,
    S34,
    S34_stoich,
    S35,
    S35_stoich,
    S36,
    S36_stoich,
    S37,
    S37_stoich,
    S38,
    S38_stoich,
    S39,
    S39_stoich,
    S3_stoich,
    S4,
    S40,
    S40_stoich,
    S41,
    S41_stoich,
    S42,
    S42_stoich,
    S43,
    S43_stoich,
    S44,
    S44_stoich,
    S45,
    S45_stoich,
    S46,
    S46_stoich,
    S47,
    S47_stoich,
    S48,
    S48_stoich,
    S49,
    S49_stoich,
    S4_stoich,
    S5,
    S50,
    S50_stoich,
    S51,
    S51_stoich,
    S5_stoich,
    S6,
    S6_stoich,
    S7,
    S7_stoich,
    S8,
    S8_stoich,
    S9,
    S9_stoich,
]
variable_names = [
    "S0",
    "S0_stoich",
    "S1",
    "S10",
    "S10_stoich",
    "S11",
    "S11_stoich",
    "S12",
    "S12_stoich",
    "S13",
    "S13_stoich",
    "S14",
    "S14_stoich",
    "S15",
    "S15_stoich",
    "S16",
    "S16_stoich",
    "S17",
    "S17_stoich",
    "S18",
    "S18_stoich",
    "S19",
    "S19_stoich",
    "S1_stoich",
    "S2",
    "S20",
    "S20_stoich",
    "S21",
    "S21_stoich",
    "S22",
    "S22_stoich",
    "S23",
    "S23_stoich",
    "S24",
    "S24_stoich",
    "S25",
    "S25_stoich",
    "S26",
    "S26_stoich",
    "S27",
    "S27_stoich",
    "S28",
    "S28_stoich",
    "S29",
    "S29_stoich",
    "S2_stoich",
    "S3",
    "S30",
    "S30_stoich",
    "S31",
    "S31_stoich",
    "S32",
    "S32_stoich",
    "S33",
    "S33_stoich",
    "S34",
    "S34_stoich",
    "S35",
    "S35_stoich",
    "S36",
    "S36_stoich",
    "S37",
    "S37_stoich",
    "S38",
    "S38_stoich",
    "S39",
    "S39_stoich",
    "S3_stoich",
    "S4",
    "S40",
    "S40_stoich",
    "S41",
    "S41_stoich",
    "S42",
    "S42_stoich",
    "S43",
    "S43_stoich",
    "S44",
    "S44_stoich",
    "S45",
    "S45_stoich",
    "S46",
    "S46_stoich",
    "S47",
    "S47_stoich",
    "S48",
    "S48_stoich",
    "S49",
    "S49_stoich",
    "S4_stoich",
    "S5",
    "S50",
    "S50_stoich",
    "S51",
    "S51_stoich",
    "S5_stoich",
    "S6",
    "S6_stoich",
    "S7",
    "S7_stoich",
    "S8",
    "S8_stoich",
    "S9",
    "S9_stoich",
]


def model(time: float, variables: tuple[float, ...]) -> tuple[float, ...]:
    (
        S0,
        S0_stoich,
        S1,
        S10,
        S10_stoich,
        S11,
        S11_stoich,
        S12,
        S12_stoich,
        S13,
        S13_stoich,
        S14,
        S14_stoich,
        S15,
        S15_stoich,
        S16,
        S16_stoich,
        S17,
        S17_stoich,
        S18,
        S18_stoich,
        S19,
        S19_stoich,
        S1_stoich,
        S2,
        S20,
        S20_stoich,
        S21,
        S21_stoich,
        S22,
        S22_stoich,
        S23,
        S23_stoich,
        S24,
        S24_stoich,
        S25,
        S25_stoich,
        S26,
        S26_stoich,
        S27,
        S27_stoich,
        S28,
        S28_stoich,
        S29,
        S29_stoich,
        S2_stoich,
        S3,
        S30,
        S30_stoich,
        S31,
        S31_stoich,
        S32,
        S32_stoich,
        S33,
        S33_stoich,
        S34,
        S34_stoich,
        S35,
        S35_stoich,
        S36,
        S36_stoich,
        S37,
        S37_stoich,
        S38,
        S38_stoich,
        S39,
        S39_stoich,
        S3_stoich,
        S4,
        S40,
        S40_stoich,
        S41,
        S41_stoich,
        S42,
        S42_stoich,
        S43,
        S43_stoich,
        S44,
        S44_stoich,
        S45,
        S45_stoich,
        S46,
        S46_stoich,
        S47,
        S47_stoich,
        S48,
        S48_stoich,
        S49,
        S49_stoich,
        S4_stoich,
        S5,
        S50,
        S50_stoich,
        S51,
        S51_stoich,
        S5_stoich,
        S6,
        S6_stoich,
        S7,
        S7_stoich,
        S8,
        S8_stoich,
        S9,
        S9_stoich,
    ) = variables
    dS0_stoich: float = math.e
    dS1_stoich: float = math.exp(math.e)
    dS2_stoich: float = 1
    dS3_stoich: float = 1
    dS4_stoich: float = math.pi
    dS5_stoich: float = 1.04719755119660
    dS6_stoich: float = (1 / 2) * math.pi
    dS7_stoich: float = -0.523598775598299
    dS8_stoich: float = 1.22777238637419
    dS9_stoich: float = -1.43067687253053
    dS10_stoich: float = 1
    dS11_stoich: float = 4
    dS12_stoich: float = -4
    dS13_stoich: float = -0.947721602131112
    dS14_stoich: float = 0.975897449330606
    dS15_stoich: float = 1
    dS16_stoich: float = math.e
    dS17_stoich: float = 2.15976625378492
    dS18_stoich: float = -5
    dS19_stoich: float = 9
    dS20_stoich: float = -1.60943791243410
    dS21_stoich: float = 0
    dS22_stoich: float = -1.6094379124341 / math.log(10)
    dS23_stoich: float = 0
    dS24_stoich: float = 1
    dS25_stoich: float = 4
    dS26_stoich: float = 5.56228172775440
    dS27_stoich: float = 16
    dS28_stoich: float = 9.61000000000000
    dS29_stoich: float = 2
    dS30_stoich: float = 2.72029410174709
    dS31_stoich: float = 0.863209366648874
    dS32_stoich: float = 0
    dS33_stoich: float = 0.373876664830236
    dS34_stoich: float = 0
    dS35_stoich: float = 2.01433821447683
    dS36_stoich: float = -math.tan(6)
    dS37_stoich: float = 1.13949392732455
    dS38_stoich: float = -1.02298638367130
    dS39_stoich: float = 4.93315487558689
    dS40_stoich: float = 0.304520293447143
    dS41_stoich: float = 2.82831545788997
    dS42_stoich: float = 1.12099946637054
    dS43_stoich: float = 1.14109666064347
    dS44_stoich: float = -1.47112767430373
    dS45_stoich: float = math.asinh(99)
    dS46_stoich: float = 0.802881971289134
    dS47_stoich: float = -0.867300527694053
    dS48_stoich: float = 1.51330668842682
    dS49_stoich: float = 5.29834236561059
    dS50_stoich: float = 1
    dS51_stoich: float = 0
    J0: float = 1
    J1: float = 1
    J2: float = 1
    J3: float = 1
    J4: float = 1
    J5: float = 1
    J6: float = 1
    J7: float = 1
    J8: float = 1
    J9: float = 1
    J10: float = 1
    J11: float = 1
    J12: float = 1
    J13: float = 1
    J14: float = 1
    J15: float = 1
    J16: float = 1
    J17: float = 1
    J18: float = 1
    J19: float = 1
    J20: float = 1
    J21: float = 1
    J22: float = 1
    J23: float = 1
    J24: float = 1
    J25: float = 1
    J26: float = 1
    J27: float = 1
    J28: float = 1
    J29: float = 1
    J30: float = 1
    J31: float = 1
    J32: float = 1
    J33: float = 1
    J34: float = 1
    J35: float = 1
    J36: float = 1
    J37: float = 1
    J38: float = 1
    J39: float = 1
    J40: float = 1
    J41: float = 1
    J42: float = 1
    J43: float = 1
    J44: float = 1
    J45: float = 1
    J46: float = 1
    J47: float = 1
    J48: float = 1
    J49: float = 1
    J50: float = 1
    J51: float = 1
    dS0_stoichdt: float = dS0_stoich
    dS1_stoichdt: float = dS1_stoich
    dS2_stoichdt: float = dS2_stoich
    dS3_stoichdt: float = dS3_stoich
    dS4_stoichdt: float = dS4_stoich
    dS5_stoichdt: float = dS5_stoich
    dS6_stoichdt: float = dS6_stoich
    dS7_stoichdt: float = dS7_stoich
    dS8_stoichdt: float = dS8_stoich
    dS9_stoichdt: float = dS9_stoich
    dS10_stoichdt: float = dS10_stoich
    dS11_stoichdt: float = dS11_stoich
    dS12_stoichdt: float = dS12_stoich
    dS13_stoichdt: float = dS13_stoich
    dS14_stoichdt: float = dS14_stoich
    dS15_stoichdt: float = dS15_stoich
    dS16_stoichdt: float = dS16_stoich
    dS17_stoichdt: float = dS17_stoich
    dS18_stoichdt: float = dS18_stoich
    dS19_stoichdt: float = dS19_stoich
    dS20_stoichdt: float = dS20_stoich
    dS21_stoichdt: float = dS21_stoich
    dS22_stoichdt: float = dS22_stoich
    dS23_stoichdt: float = dS23_stoich
    dS24_stoichdt: float = dS24_stoich
    dS25_stoichdt: float = dS25_stoich
    dS26_stoichdt: float = dS26_stoich
    dS27_stoichdt: float = dS27_stoich
    dS28_stoichdt: float = dS28_stoich
    dS29_stoichdt: float = dS29_stoich
    dS30_stoichdt: float = dS30_stoich
    dS31_stoichdt: float = dS31_stoich
    dS32_stoichdt: float = dS32_stoich
    dS33_stoichdt: float = dS33_stoich
    dS34_stoichdt: float = dS34_stoich
    dS35_stoichdt: float = dS35_stoich
    dS36_stoichdt: float = dS36_stoich
    dS37_stoichdt: float = dS37_stoich
    dS38_stoichdt: float = dS38_stoich
    dS39_stoichdt: float = dS39_stoich
    dS40_stoichdt: float = dS40_stoich
    dS41_stoichdt: float = dS41_stoich
    dS42_stoichdt: float = dS42_stoich
    dS43_stoichdt: float = dS43_stoich
    dS44_stoichdt: float = dS44_stoich
    dS45_stoichdt: float = dS45_stoich
    dS46_stoichdt: float = dS46_stoich
    dS47_stoichdt: float = dS47_stoich
    dS48_stoichdt: float = dS48_stoich
    dS49_stoichdt: float = dS49_stoich
    dS50_stoichdt: float = dS50_stoich
    dS51_stoichdt: float = dS51_stoich
    dS0dt: float = J0 * S0_stoich
    dS1dt: float = J1 * S1_stoich
    dS2dt: float = J2 * S2_stoich
    dS3dt: float = J3 * S3_stoich
    dS4dt: float = J4 * S4_stoich
    dS5dt: float = J5 * S5_stoich
    dS6dt: float = J6 * S6_stoich
    dS7dt: float = J7 * S7_stoich
    dS8dt: float = J8 * S8_stoich
    dS9dt: float = J9 * S9_stoich
    dS10dt: float = J10 * S10_stoich
    dS11dt: float = J11 * S11_stoich
    dS12dt: float = J12 * S12_stoich
    dS13dt: float = J13 * S13_stoich
    dS14dt: float = J14 * S14_stoich
    dS15dt: float = J15 * S15_stoich
    dS16dt: float = J16 * S16_stoich
    dS17dt: float = J17 * S17_stoich
    dS18dt: float = J18 * S18_stoich
    dS19dt: float = J19 * S19_stoich
    dS20dt: float = J20 * S20_stoich
    dS21dt: float = J21 * S21_stoich
    dS22dt: float = J22 * S22_stoich
    dS23dt: float = J23 * S23_stoich
    dS24dt: float = J24 * S24_stoich
    dS25dt: float = J25 * S25_stoich
    dS26dt: float = J26 * S26_stoich
    dS27dt: float = J27 * S27_stoich
    dS28dt: float = J28 * S28_stoich
    dS29dt: float = J29 * S29_stoich
    dS30dt: float = J30 * S30_stoich
    dS31dt: float = J31 * S31_stoich
    dS32dt: float = J32 * S32_stoich
    dS33dt: float = J33 * S33_stoich
    dS34dt: float = J34 * S34_stoich
    dS35dt: float = J35 * S35_stoich
    dS36dt: float = J36 * S36_stoich
    dS37dt: float = J37 * S37_stoich
    dS38dt: float = J38 * S38_stoich
    dS39dt: float = J39 * S39_stoich
    dS40dt: float = J40 * S40_stoich
    dS41dt: float = J41 * S41_stoich
    dS42dt: float = J42 * S42_stoich
    dS43dt: float = J43 * S43_stoich
    dS44dt: float = J44 * S44_stoich
    dS45dt: float = J45 * S45_stoich
    dS46dt: float = J46 * S46_stoich
    dS47dt: float = J47 * S47_stoich
    dS48dt: float = J48 * S48_stoich
    dS49dt: float = J49 * S49_stoich
    dS50dt: float = J50 * S50_stoich
    dS51dt: float = J51 * S51_stoich
    return (
        dS0dt,
        dS0_stoichdt,
        dS1dt,
        dS10dt,
        dS10_stoichdt,
        dS11dt,
        dS11_stoichdt,
        dS12dt,
        dS12_stoichdt,
        dS13dt,
        dS13_stoichdt,
        dS14dt,
        dS14_stoichdt,
        dS15dt,
        dS15_stoichdt,
        dS16dt,
        dS16_stoichdt,
        dS17dt,
        dS17_stoichdt,
        dS18dt,
        dS18_stoichdt,
        dS19dt,
        dS19_stoichdt,
        dS1_stoichdt,
        dS2dt,
        dS20dt,
        dS20_stoichdt,
        dS21dt,
        dS21_stoichdt,
        dS22dt,
        dS22_stoichdt,
        dS23dt,
        dS23_stoichdt,
        dS24dt,
        dS24_stoichdt,
        dS25dt,
        dS25_stoichdt,
        dS26dt,
        dS26_stoichdt,
        dS27dt,
        dS27_stoichdt,
        dS28dt,
        dS28_stoichdt,
        dS29dt,
        dS29_stoichdt,
        dS2_stoichdt,
        dS3dt,
        dS30dt,
        dS30_stoichdt,
        dS31dt,
        dS31_stoichdt,
        dS32dt,
        dS32_stoichdt,
        dS33dt,
        dS33_stoichdt,
        dS34dt,
        dS34_stoichdt,
        dS35dt,
        dS35_stoichdt,
        dS36dt,
        dS36_stoichdt,
        dS37dt,
        dS37_stoichdt,
        dS38dt,
        dS38_stoichdt,
        dS39dt,
        dS39_stoichdt,
        dS3_stoichdt,
        dS4dt,
        dS40dt,
        dS40_stoichdt,
        dS41dt,
        dS41_stoichdt,
        dS42dt,
        dS42_stoichdt,
        dS43dt,
        dS43_stoichdt,
        dS44dt,
        dS44_stoichdt,
        dS45dt,
        dS45_stoichdt,
        dS46dt,
        dS46_stoichdt,
        dS47dt,
        dS47_stoichdt,
        dS48dt,
        dS48_stoichdt,
        dS49dt,
        dS49_stoichdt,
        dS4_stoichdt,
        dS5dt,
        dS50dt,
        dS50_stoichdt,
        dS51dt,
        dS51_stoichdt,
        dS5_stoichdt,
        dS6dt,
        dS6_stoichdt,
        dS7dt,
        dS7_stoichdt,
        dS8dt,
        dS8_stoichdt,
        dS9dt,
        dS9_stoichdt,
    )


def derived(time: float, variables: tuple[float, ...]) -> dict[str, float]:
    (
        S0,
        S0_stoich,
        S1,
        S10,
        S10_stoich,
        S11,
        S11_stoich,
        S12,
        S12_stoich,
        S13,
        S13_stoich,
        S14,
        S14_stoich,
        S15,
        S15_stoich,
        S16,
        S16_stoich,
        S17,
        S17_stoich,
        S18,
        S18_stoich,
        S19,
        S19_stoich,
        S1_stoich,
        S2,
        S20,
        S20_stoich,
        S21,
        S21_stoich,
        S22,
        S22_stoich,
        S23,
        S23_stoich,
        S24,
        S24_stoich,
        S25,
        S25_stoich,
        S26,
        S26_stoich,
        S27,
        S27_stoich,
        S28,
        S28_stoich,
        S29,
        S29_stoich,
        S2_stoich,
        S3,
        S30,
        S30_stoich,
        S31,
        S31_stoich,
        S32,
        S32_stoich,
        S33,
        S33_stoich,
        S34,
        S34_stoich,
        S35,
        S35_stoich,
        S36,
        S36_stoich,
        S37,
        S37_stoich,
        S38,
        S38_stoich,
        S39,
        S39_stoich,
        S3_stoich,
        S4,
        S40,
        S40_stoich,
        S41,
        S41_stoich,
        S42,
        S42_stoich,
        S43,
        S43_stoich,
        S44,
        S44_stoich,
        S45,
        S45_stoich,
        S46,
        S46_stoich,
        S47,
        S47_stoich,
        S48,
        S48_stoich,
        S49,
        S49_stoich,
        S4_stoich,
        S5,
        S50,
        S50_stoich,
        S51,
        S51_stoich,
        S5_stoich,
        S6,
        S6_stoich,
        S7,
        S7_stoich,
        S8,
        S8_stoich,
        S9,
        S9_stoich,
    ) = variables
    dS0_stoich: float = math.e
    dS1_stoich: float = math.exp(math.e)
    dS2_stoich: float = 1
    dS3_stoich: float = 1
    dS4_stoich: float = math.pi
    dS5_stoich: float = 1.04719755119660
    dS6_stoich: float = (1 / 2) * math.pi
    dS7_stoich: float = -0.523598775598299
    dS8_stoich: float = 1.22777238637419
    dS9_stoich: float = -1.43067687253053
    dS10_stoich: float = 1
    dS11_stoich: float = 4
    dS12_stoich: float = -4
    dS13_stoich: float = -0.947721602131112
    dS14_stoich: float = 0.975897449330606
    dS15_stoich: float = 1
    dS16_stoich: float = math.e
    dS17_stoich: float = 2.15976625378492
    dS18_stoich: float = -5
    dS19_stoich: float = 9
    dS20_stoich: float = -1.60943791243410
    dS21_stoich: float = 0
    dS22_stoich: float = -1.6094379124341 / math.log(10)
    dS23_stoich: float = 0
    dS24_stoich: float = 1
    dS25_stoich: float = 4
    dS26_stoich: float = 5.56228172775440
    dS27_stoich: float = 16
    dS28_stoich: float = 9.61000000000000
    dS29_stoich: float = 2
    dS30_stoich: float = 2.72029410174709
    dS31_stoich: float = 0.863209366648874
    dS32_stoich: float = 0
    dS33_stoich: float = 0.373876664830236
    dS34_stoich: float = 0
    dS35_stoich: float = 2.01433821447683
    dS36_stoich: float = -math.tan(6)
    dS37_stoich: float = 1.13949392732455
    dS38_stoich: float = -1.02298638367130
    dS39_stoich: float = 4.93315487558689
    dS40_stoich: float = 0.304520293447143
    dS41_stoich: float = 2.82831545788997
    dS42_stoich: float = 1.12099946637054
    dS43_stoich: float = 1.14109666064347
    dS44_stoich: float = -1.47112767430373
    dS45_stoich: float = math.asinh(99)
    dS46_stoich: float = 0.802881971289134
    dS47_stoich: float = -0.867300527694053
    dS48_stoich: float = 1.51330668842682
    dS49_stoich: float = 5.29834236561059
    dS50_stoich: float = 1
    dS51_stoich: float = 0
    J0: float = 1
    J1: float = 1
    J2: float = 1
    J3: float = 1
    J4: float = 1
    J5: float = 1
    J6: float = 1
    J7: float = 1
    J8: float = 1
    J9: float = 1
    J10: float = 1
    J11: float = 1
    J12: float = 1
    J13: float = 1
    J14: float = 1
    J15: float = 1
    J16: float = 1
    J17: float = 1
    J18: float = 1
    J19: float = 1
    J20: float = 1
    J21: float = 1
    J22: float = 1
    J23: float = 1
    J24: float = 1
    J25: float = 1
    J26: float = 1
    J27: float = 1
    J28: float = 1
    J29: float = 1
    J30: float = 1
    J31: float = 1
    J32: float = 1
    J33: float = 1
    J34: float = 1
    J35: float = 1
    J36: float = 1
    J37: float = 1
    J38: float = 1
    J39: float = 1
    J40: float = 1
    J41: float = 1
    J42: float = 1
    J43: float = 1
    J44: float = 1
    J45: float = 1
    J46: float = 1
    J47: float = 1
    J48: float = 1
    J49: float = 1
    J50: float = 1
    J51: float = 1
    return {
        "dS0_stoich": dS0_stoich,
        "dS1_stoich": dS1_stoich,
        "dS2_stoich": dS2_stoich,
        "dS3_stoich": dS3_stoich,
        "dS4_stoich": dS4_stoich,
        "dS5_stoich": dS5_stoich,
        "dS6_stoich": dS6_stoich,
        "dS7_stoich": dS7_stoich,
        "dS8_stoich": dS8_stoich,
        "dS9_stoich": dS9_stoich,
        "dS10_stoich": dS10_stoich,
        "dS11_stoich": dS11_stoich,
        "dS12_stoich": dS12_stoich,
        "dS13_stoich": dS13_stoich,
        "dS14_stoich": dS14_stoich,
        "dS15_stoich": dS15_stoich,
        "dS16_stoich": dS16_stoich,
        "dS17_stoich": dS17_stoich,
        "dS18_stoich": dS18_stoich,
        "dS19_stoich": dS19_stoich,
        "dS20_stoich": dS20_stoich,
        "dS21_stoich": dS21_stoich,
        "dS22_stoich": dS22_stoich,
        "dS23_stoich": dS23_stoich,
        "dS24_stoich": dS24_stoich,
        "dS25_stoich": dS25_stoich,
        "dS26_stoich": dS26_stoich,
        "dS27_stoich": dS27_stoich,
        "dS28_stoich": dS28_stoich,
        "dS29_stoich": dS29_stoich,
        "dS30_stoich": dS30_stoich,
        "dS31_stoich": dS31_stoich,
        "dS32_stoich": dS32_stoich,
        "dS33_stoich": dS33_stoich,
        "dS34_stoich": dS34_stoich,
        "dS35_stoich": dS35_stoich,
        "dS36_stoich": dS36_stoich,
        "dS37_stoich": dS37_stoich,
        "dS38_stoich": dS38_stoich,
        "dS39_stoich": dS39_stoich,
        "dS40_stoich": dS40_stoich,
        "dS41_stoich": dS41_stoich,
        "dS42_stoich": dS42_stoich,
        "dS43_stoich": dS43_stoich,
        "dS44_stoich": dS44_stoich,
        "dS45_stoich": dS45_stoich,
        "dS46_stoich": dS46_stoich,
        "dS47_stoich": dS47_stoich,
        "dS48_stoich": dS48_stoich,
        "dS49_stoich": dS49_stoich,
        "dS50_stoich": dS50_stoich,
        "dS51_stoich": dS51_stoich,
        "J0": J0,
        "J1": J1,
        "J2": J2,
        "J3": J3,
        "J4": J4,
        "J5": J5,
        "J6": J6,
        "J7": J7,
        "J8": J8,
        "J9": J9,
        "J10": J10,
        "J11": J11,
        "J12": J12,
        "J13": J13,
        "J14": J14,
        "J15": J15,
        "J16": J16,
        "J17": J17,
        "J18": J18,
        "J19": J19,
        "J20": J20,
        "J21": J21,
        "J22": J22,
        "J23": J23,
        "J24": J24,
        "J25": J25,
        "J26": J26,
        "J27": J27,
        "J28": J28,
        "J29": J29,
        "J30": J30,
        "J31": J31,
        "J32": J32,
        "J33": J33,
        "J34": J34,
        "J35": J35,
        "J36": J36,
        "J37": J37,
        "J38": J38,
        "J39": J39,
        "J40": J40,
        "J41": J41,
        "J42": J42,
        "J43": J43,
        "J44": J44,
        "J45": J45,
        "J46": J46,
        "J47": J47,
        "J48": J48,
        "J49": J49,
        "J50": J50,
        "J51": J51,
    }
